local agent_helper = require("scripts/agent/agent_helper")
AgentAdapter = {
	is_init = false,
	is_login_verify_ing = false,
	login_callback = nil,
	force_logout = false,
	login_verify_url = "cls.mg51.youyannet.com/ap1/login_verify.php",
	uid = "",
	is_create_role = false,
}

--//按返回键回调在这里，退出
function PlatformAdapter:OpenExitDialog()
	agent_helper:Exit(function(arg)
		if "true" == arg then
			AdapterToLua:endGame()
		else
			local format = { title = "退出", message = "退出游戏?", positive = "确定", negative = "取消", }
			PlatformAdapter:OpenAlertDialog(format, function(result)
				if "positive" == result then
					AdapterToLua:endGame()
			 	end
			end)
		end
	end)
end

-- 初始化
function AgentAdapter:Init()

	if self.is_init then return end
	self.uid = string.gsub((AdapterToLua:getInstance():getDataCache("PRVE_ACCOUNT_NAME") or ""), self:GetSpid() .. "_", "")
	self.is_init = true
	AgentMs:InitLocalPush()
	PlatformBinder:JsonBind("call_agent_logout", function(arg)
		self:LogoutCallback(arg)
		return true
	end)
end

-- 平台ID
function AgentAdapter:GetSpid()
	return "ap1"
end

-- 平台帐号唯一标识
function AgentAdapter:GetOpenId()
	return self.uid
end

-- 加前辍的平台帐号，全平台唯一
function AgentAdapter:GetPlatName()
	return "ap1_".. self.uid
end

--获得游戏名字
function AgentAdapter:GetGameName()
	local path = "agentres/game_name.txt"
	if cc.FileUtils:getInstance():isFileExist(path) then
		local game_name = UtilEx:readText(path)
		print("game_name === ", tostring(game_name))
		return tostring(game_name)
	end
	return "缥缈奇缘"
end

-- 获得logo资源名
function AgentAdapter:GetLogoResName()
	return "agentres/logo.png"
end

function AgentAdapter:Login(callback)
	if self.is_login_verify_ing then
		SysMsgCtrl.Instance:ErrorRemind("正在登录验证中，请稍等...", true)
		return
	end
	self.login_callback = callback
	agent_helper:Login(LUA_CALLBACK(self, self.LoginCallback))--设置登录回调 

end

function AgentAdapter:OnClickBackLogin()
	agent_helper:Logout()
end

function AgentAdapter:OnClickRestartGame()
	print("OnClickRestartGame")
	agent_helper:Logout()
end


function AgentAdapter:LoginCallback(result)  --登录后回调

	local verify_callback = function(url, arg, data, size)
		
		self.is_login_verify_ing = false
		if size <= 0 then
			return
		end
		
		local ret_t = cjson.decode(data)
		if nil == ret_t or 0 ~= ret_t.ret or nil == ret_t.user then
			return
		end
	
		self.uid = ret_t.user.uid
		LoginController.Instance:SetLoginUserData(self:GetPlatName(), ret_t.user)
		self.login_callback(self:GetPlatName())

		agent_helper:ShowFloatButton()
	end

	self.is_login_verify_ing = true
	
	local real_url = string.format("%s?spid=%s&device=%s&result=%s", self.login_verify_url, self:GetSpid(), tostring(PlatformAdapter.GetPhoneUniqueId()), result)
	Log("log_real_url====" .. real_url)
	HttpClient:Request(real_url, "", verify_callback)

	return false
	
end

function AgentAdapter:LogoutCallback(result)--注销回调
	print("ReStart")
	self.uid = ""
	if not LoginController.Instance:AgentLoginViewIsOpen() then
		ReStart()--跳到登录界面
	end
	return true
end

function AgentAdapter:Pay(role_id, role_name, amount, server_id, callback)--购买
	if self.uid == "" then
		SysMsgCtrl.Instance:ErrorRemind("uid为空，请联系客服")
		return
	end
	
	local user_vo = GameVoManager.Instance:GetUserVo()
	local data = {}
	data.price = amount
	data.amount = amount * 10
	data.description = data.amount .. "元宝"
	data.rid = role_id
	data.platformUserId = self.uid
	data.platformUserName = role_name
	data.sid = server_id
	data.serverName = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
	data.moneyName = "元宝"
	data.exchange = 10
	data.roleName = role_name
	data.extra = server_id .. "_" .. self:GetPlatName() .. "_" .. os.time()
	agent_helper:Pay(cjson.encode(data), callback)
end

-- 创建角色上报
function AgentAdapter:ReportOnCreateRole(role_name)
	if not is_create_role then
		self.is_create_role = true
	end
end

-- 进入游戏上报
function AgentAdapter:SubmitRoleData(role_id, role_name, role_level, zone_id, zone_name)
	if self.is_create_role then
		self:SubmitInfo(0)
		self.is_create_role = false
	end
	self:SubmitInfo(1)
end

--  升级上报
function AgentAdapter:ReportOnRoleLevUp(role_id, role_name, role_level, zone_id, zone_name)
	self:SubmitInfo(2)
end

function AgentAdapter:SubmitInfo(type)
	local role_vo = GameVoManager.Instance:GetMainRoleVo()
	local user_vo = GameVoManager.Instance:GetUserVo()
	local info = {}
	info.rid = tostring(role_vo.role_id)
	info.roleName = role_vo.name
	info.platformUserId = tostring(self.uid)
	info.platformUserName = tostring(self.uid)
	info.sid = tostring(user_vo.plat_server_id)
	info.serverName = user_vo.plat_server_id .. "服-" .. user_vo.plat_server_name
	info.roleLevel = tostring(role_vo.level)
	info.sub_type = type
	--上报创建角色时间
	info.roleCTime = role_vo.create_time or 0
	Log("send_user_info====" .. cjson.encode(info))
	PlatformBinder:JsonCall("send_user_info", cjson.encode(info))
end

--是否支持动态下载
function AgentAdapter:IsDynamicDownloadRes()
	return true
end
